==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/veo35k.cpp <==
/* @lastChanged: "1998-04-20  19:16"
 * @filename:    veo35k.cpp
 * @purpose:     "DCOMx_Functions Stub (replaces veo35.cpp veo36.cpp veo38.cpp ven36.cpp ven38.cpp ven38a veo02.c ven78.cpp"
 * @release:     7.2.0.0
 * @see:         ""
 *
 * @copyright:   "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 */

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/
#include "ggg00.h"
#include "gsp00.h"
#include "geo00k.h"

#include "heo35k.h"
#include "heo60.h"
#include "gen500.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#ifdef NO_INLINES
# define _INLINE
#else
# define _INLINE	inline
#endif



/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

#define INFO_DCOM_NYI  11000,INFO_TYPE,"DCOM    ","%s: Not yet implemented"

/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL VARIABLES                                                          *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

#if defined (_WIN32)

/*---------------------------------------------------------------------------*/
/*           Windows NT: Module not used, view vos35k.cpp !!!!!!!            */
/*---------------------------------------------------------------------------*/
#error Module not used, view vos35k.cpp !!!!!!!

#else

/* undefined symbols from ven35.o:
eo36ParamInfo
eo38VDcomReleaseAll
eo38ReleaseInstance
eo38CoGetClassObject
eo38CoInitialize
eo38CoCreateInstance
eo38UnInitialize
 */
externC void eo36ParamInfo ( tsp_dcom_paraminfo_parms *parms ) {}
externC void eo38VDcomReleaseAll ( void ) {}
externC void eo38ReleaseInstance ( tsp_dcom_release_instance_parms * parms ) {}
externC void eo38CoGetClassObject ( tsp_dcom_co_create_instance_parms * parms ) {}
externC BOOLEAN eo38CoInitialize ( void ) { return TRUE; }
externC void eo38CoCreateInstance ( tsp_dcom_co_create_instance_parms * parms ) {}
externC void eo38UnInitialize ( void ) {}

/*
 * vdcom_ interface
 */
externC void vdcom_monitor_open( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO00 ("vdcom_monitor_open");

  parms->session_handle   = NULL;
  parms->retcode          = -1;
  parms->idispatch        = NULL;

  MSGD(( INFO_DCOM_NYI, "vdcom_monitor_open" ));

  return;
}

externC void vdcom_monitor_next( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO00 ("vdcom_monitor_next");

  parms->retcode          = -1;
  parms->idispatch        = NULL;

  MSGD(( INFO_DCOM_NYI, "vdcom_monitor_next" ));

  return;
}

externC void vdcom_monitor_close( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO00 ("vdcom_monitor_close");

  MSGD(( INFO_DCOM_NYI, "vdcom_monitor_close" ));

  return;
}

externC void vdcom_iid_ilivecachespec ( tsp00_C16*      pIId )
{
  ROUTINE_DBG_MEO00 ("vdcom_iid_ilivecachespec");

  MSGD(( INFO_DCOM_NYI, "vdcom_iid_ilivecachespec" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_co_get_classobject ( bool            fDebug,
                                        void            *pInstance,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_co_get_classobject");

  MSGD(( INFO_DCOM_NYI, "vdcom_co_get_classobject" ));
  *pOk = false;   
  pErrtext->rawAssign("UNIX: Not implemented");

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_co_create_instance ( void            *pInstance,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_co_create_instance");

  MSGD(( INFO_DCOM_NYI, "vdcom_co_create_instance" ));
  *pOk = false;   
  pErrtext->rawAssign("UNIX: Not implemented");

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_paraminfo ( bool             debug_flag,
							   void            *pParamInfo,
                               bool            *pOk,
                               tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_paraminfo");

  MSGD(( INFO_DCOM_NYI, "vdcom_paraminfo" ));
  *pOk = false;   
  pErrtext->rawAssign("UNIX: Not implemented");

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_create_instance ( bool            fDebug,
                                     void            *pInstance,
                                     bool            *pOk,
                                     tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_create_instance");

  MSGD(( INFO_DCOM_NYI, "vdcom_create_instance" ));
  *pOk = false;   
  pErrtext->rawAssign("UNIX: Not implemented");

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_release_instance ( void            *pParamInfo,
                                      bool            *pOk,
                                      tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_release_instance");

  MSGD(( INFO_DCOM_NYI, "vdcom_release_instance" ));
  *pOk = false;   
  pErrtext->rawAssign("UNIX: Not implemented");

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_release_all ( )
{
  ROUTINE_DBG_MEO00 ("vdcom_release_all");

  MSGD(( INFO_DCOM_NYI, "vdcom_release_all" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_dispatch ( void *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_dispatch");

  MSGD(( INFO_DCOM_NYI, "vdcom_dispatch" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_dbproc ( void *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_dbproc");

  MSGD(( INFO_DCOM_NYI, "vdcom_dbproc" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_trans_end ( void *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_trans_end");

  MSGD(( INFO_DCOM_NYI, "vdcom_trans_end" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_get_dispaddr ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_get_dispaddr");

  MSGD(( INFO_DCOM_NYI, "vdcom_get_dispaddr" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_init_sink ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_init_sink");

  MSGD(( INFO_DCOM_NYI, "vdcom_init_sink" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_invalidate ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_invalidate");

  MSGD(( INFO_DCOM_NYI, "vdcom_invalidate" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void eo35_VDCOMTransfer ( void *pTransportBuffer, 
								  bool *pOk,
								  tsp00_ErrText *pErrtext )
{
  ROUTINE_DBG_MEO00 ("eo35_VDCOMTransfer");

  MSGD(( INFO_DCOM_NYI, "eo35_VDCOMTransfer" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC bool eo35_RemoveDCOMi ( void  )
{
  ROUTINE_DBG_MEO00 ("eo35_RemoveDCOMi");

  MSGD(( INFO_DCOM_NYI, "eo35_RemoveDCOMi" ));
  return false;
}

/*---------------------------------------------------------------------------*/

externC void eo35_DCOM0 ( void  )
{
  ROUTINE_DBG_MEO00 ("eo35_DCOM0");

  MSGD(( INFO_DCOM_NYI, "eo35_DCOM0" ));
  return;
}

/*------------- +++++ PTS 1106505 FF +++++++++++++++ ------------------------*/

externC void eo38CTraceBack( tsp00_Addr )
{
}

#endif


/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/veo35k.cpp <==
/* @lastChanged: "1998-04-20  19:16"
 * @filename:    veo35k.cpp
 * @purpose:     "DCOMx_Functions Stub (replaces veo35.cpp veo36.cpp veo38.cpp ven36.cpp ven38.cpp ven38a veo02.c ven78.cpp"
 * @release:     7.2.0.0
 * @see:         ""
 *
 * @copyright:   "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 */

/* ************************************************************* */
/* PTS 1112663   eliminate livecacheProxy  FF 15.Nov.2001 7.4.02 */
/* ************************************************************* */

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/
#include "ggg00.h"
#include "gsp00.h"

#include "heo35k.h"
#include "heo60.h"
#include "gen500.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#ifdef NO_INLINES
# define _INLINE
#else
# define _INLINE	inline
#endif



/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

#define INFO_DCOM_NYI  11000,INFO_TYPE,"DCOM    ","%s: Not yet implemented"

/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL VARIABLES                                                          *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

#if defined (_WIN32)

/*---------------------------------------------------------------------------*/
/*           Windows NT: Module not used, view vos35k.cpp !!!!!!!            */
/*---------------------------------------------------------------------------*/
#error Module not used, view vos35k.cpp !!!!!!!

#else

/* undefined symbols from ven35.o:
eo36ParamInfo
eo38VDcomReleaseAll
eo38ReleaseInstance
eo38CoGetClassObject
eo38CoInitialize
eo38CoCreateInstance
eo38UnInitialize
 */
externC void eo36ParamInfo ( tsp_dcom_paraminfo_parms *parms ) {}
externC void eo38VDcomReleaseAll ( void ) {}
externC void eo38ReleaseInstance ( tsp_dcom_release_instance_parms * parms ) {}
externC void eo38CoGetClassObject ( tsp_dcom_co_create_instance_parms * parms ) {}
externC BOOLEAN eo38CoInitialize ( void ) { return TRUE; }
externC void eo38UnInitialize ( void ) {}

/*
 * vdcom_ interface
 */
externC void vdcom_monitor_open( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO00 ("vdcom_monitor_open");

  parms->session_handle   = NULL;
  parms->retcode          = -1;
  parms->idispatch        = NULL;

  MSGD(( INFO_DCOM_NYI, "vdcom_monitor_open" ));

  return;
}

externC void vdcom_monitor_next( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO00 ("vdcom_monitor_next");

  parms->retcode          = -1;
  parms->idispatch        = NULL;

  MSGD(( INFO_DCOM_NYI, "vdcom_monitor_next" ));

  return;
}

externC void vdcom_monitor_close( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO00 ("vdcom_monitor_close");

  MSGD(( INFO_DCOM_NYI, "vdcom_monitor_close" ));

  return;
}

externC void vdcom_iid_ilivecachespec ( tsp00_C16*      pIId )
{
  ROUTINE_DBG_MEO00 ("vdcom_iid_ilivecachespec");

  MSGD(( INFO_DCOM_NYI, "vdcom_iid_ilivecachespec" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_co_get_classobject ( void            *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_co_get_classobject");

  MSGD(( INFO_DCOM_NYI, "vdcom_co_get_classobject" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_co_create_instance ( void            *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_co_create_instance");

  MSGD(( INFO_DCOM_NYI, "vdcom_co_create_instance" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_paraminfo ( void            *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_paraminfo");

  MSGD(( INFO_DCOM_NYI, "vdcom_paraminfo" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_create_instance ( void            *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_create_instance");

  MSGD(( INFO_DCOM_NYI, "vdcom_create_instance" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_release_instance ( void            *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_release_instance");

  MSGD(( INFO_DCOM_NYI, "vdcom_release_instance" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_release_all ( )
{
  ROUTINE_DBG_MEO00 ("vdcom_release_all");

  MSGD(( INFO_DCOM_NYI, "vdcom_release_all" ));

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_dbproc ( void *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_dbproc");

  MSGD(( INFO_DCOM_NYI, "vdcom_dbproc" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_trans_end ( void *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_trans_end");

  MSGD(( INFO_DCOM_NYI, "vdcom_trans_end" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_get_dispaddr ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_get_dispaddr");

  MSGD(( INFO_DCOM_NYI, "vdcom_get_dispaddr" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_init_sink ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_init_sink");

  MSGD(( INFO_DCOM_NYI, "vdcom_init_sink" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_invalidate ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_invalidate");

  MSGD(( INFO_DCOM_NYI, "vdcom_invalidate" ));
  return;
}

/*---------------------------------------------------------------------------*/

externC void eo38CTraceBack( tsp00_Addr )
{
}

#endif


/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
